@@ -123,8 +123,10 @@ class Account(ABC):
     name: str
     account_type: AccountType
     user_profile: UserProfile
+    api_key: str
 
-    def __init__(self, wise_account: wise_models.Account, user_profile: UserProfile):
+    def __init__(self, api_key: str, wise_account: wise_models.Account, user_profile: UserProfile):
+        self.api_key = api_key
         self.id = wise_account.id
         self.currency = global_common.get_enum_from_value(wise_account.currency, global_common.Currency)
         self.balance = Decimal(str(wise_account.cashAmount.value))
@@ -132,14 +134,14 @@ class Account(ABC):
         self.account_type = global_common.get_enum_from_value(wise_account.type, AccountType)
         self.user_profile = user_profile
 
-    def transfer(self, api_key: str, recipient: Recipient, receiving_amount: Decimal, to_currency: global_common.Currency, reference: str) -> Transfer:
-        transfer: Transfer = Transfer.execute(api_key, receiving_amount, recipient, self.currency, to_currency, reference, self.user_profile.type)
+    def transfer(self, recipient: Recipient, receiving_amount: Decimal, to_currency: global_common.Currency, reference: str) -> Transfer:
+        transfer: Transfer = Transfer.execute(self.api_key, receiving_amount, recipient, self.currency, to_currency, reference, self.user_profile.type)
 
         if transfer.is_successful:
             if isinstance(self, CashAccount):
-                self.balance = Account.get_by_profile_type_and_currency(api_key, self.user_profile.type, self.currency).balance
+                self.balance = Account.get_by_profile_type_and_currency(self.api_key, self.user_profile.type, self.currency).balance
             else:
-                self.balance = ReserveAccount.get_reserve_account_by_profile_type_currency_and_name(api_key, self.user_profile.type, self.currency, self.name, False).balance
+                self.balance = ReserveAccount.get_reserve_account_by_profile_type_currency_and_name(self.api_key, self.user_profile.type, self.currency, self.name, False).balance
 
         return transfer
 
@@ -161,9 +163,9 @@ class Account(ABC):
         for wise_account in wise_models.Account.call(api_key, user_profile.id):
             account_type: AccountType = global_common.get_enum_from_value(wise_account.type, AccountType)
             if account_type == AccountType.CashAccount:
-                accounts_list.append(CashAccount(wise_account, user_profile))
+                accounts_list.append(CashAccount(api_key, wise_account, user_profile))
             elif account_type == AccountType.ReserveAccount:
-                accounts_list.append(ReserveAccount(wise_account, user_profile))
+                accounts_list.append(ReserveAccount(api_key, wise_account, user_profile))
 
         return accounts_list
 
@@ -180,8 +182,8 @@ class Account(ABC):
 class ReserveAccount(Account):
     name: str
 
-    def __init__(self, wise_account: wise_models.Account, user_profile: UserProfile):
-        super().__init__(wise_account, user_profile)
+    def __init__(self, api_key: str, wise_account: wise_models.Account, user_profile: UserProfile):
+        super().__init__(api_key, wise_account, user_profile)
         self.name = wise_account.name
 
     @classmethod
@@ -234,8 +236,8 @@ class ReserveAccount(Account):
 @dataclass
 class CashAccount(Account):
 
-    def __init__(self, wise_account: wise_models.Account, user_profile: UserProfile):
-        super().__init__(wise_account, user_profile)
+    def __init__(self, api_key: str, wise_account: wise_models.Account, user_profile: UserProfile):
+        super().__init__(api_key, wise_account, user_profile)
 
     @classmethod
     def get_all_by_profile_type(cls, api_key: str, profile_type: ProfileType) -> List["CashAccount"]:  # type: ignore
